@echo off
rem --- Comment to enable shell debugging


rem -----------------------------------------------------------------------------
rem secure-properties.bat - Start the encrypt utility to secure configuration properties
rem
rem This script is provided to start the OneLogin secure properties utility
rem in Linux/Unix/Mac OSX environments. It works as follows:
rem
rem 1. Checks for and validates the LDC_HOME environment, which must reference
rem    the directory where the OneLogin secure properties utility is installed.
rem    Other directories, including: bin, conf, logs are expected to be direct
rem    child directories below LDC_HOME.
rem
rem 2. If LDC_HOME is not set, it attempts to find it relative to the current
rem    working directory or the immediate parent directory.
rem
rem 3. Constructs the path to the LDAP Directory Connector jar file at:
rem    LDC_HOME/libs/onelogin-ldc.jar
rem    and ensure it exists.
rem
rem 4. Checks If SECURE_PASSWORD is set, this will be used to encrypt the properties.
rem
rem 5. Constructs command line options.
rem
rem 6. Launches the JVM on the OneLogin secure properties utility.
rem
rem This utility generates encrypted configuration values to be added to the ldc.conf configuration file
rem -----------------------------------------------------------------------------
rem

setlocal


rem --- Enable Debug
rem
rem    DEBUG - used to enable/disable DEBUG-level logging by setting
rem          a global Property value referencing configuration file:
rem          LDC_HOME/conf/logback-debug.xml  (default=false)
rem
set DEBUG=false
echo DEBUG: %DEBUG%

rem --- Flag used to run as a foreground process or a background process.
rem
rem    BACKGROUND - used by this script to start the Java Virtual Machine as
rem          a background process independent from the shell that started it
rem          or as a forground process under terminal control.
rem
set BACKGROUND=false

rem --- The Java JAR file containing LDAP Directory Connector executable code

set JAR_FILE_NAME=onelogin-ldc.jar

rem --- Check for or set the LDAP Connector Home directory
if defined LDC_HOME (
	if not exist "%LDC_HOME%\" (
		echo [FATAL] - the LDC_HOME value ^(%LDC_HOME%^) is not a valid directory path
		echo           1. Check the environment value of LDC_HOME
		echo           2. Ensure the directory exists, is readable and contains the 'libs' directory
		echo              containing the %JAR_FILE_NAME% file
		exit /b 1
	)
) else (
	if exist .\libs\%JAR_FILE_NAME% (
		set LDC_HOME=.
	) else (
		if exist ..\libs\%JAR_FILE_NAME% (
			set LDC_HOME=..
		) else (
			echo [FATAL] - the LDC_HOME value is not set and could not be guessed
			echo           1. Set LDC_HOME value to your LDAP Directory Connector installation directory
			echo              Example: set LDC_HOME=C:\onelogin-ldc-2.2.12
			echo           2. or invoke this script from the directory where you installed the LDAP Directory Connector
			echo              Example: cd C:\onelogin-ldc-2.2.12; .\bin\secure-properties.bat
			echo           3. or invoke this script from the directory containing this script
			echo              Example: cd C:\onelogin-ldc-2.2.12/bin; .\ssecure-properties.bat
			exit /b 1
		)
	)
)

rem --- Check for the executable JAR file

set JAR_PATH="%LDC_HOME%\libs\%JAR_FILE_NAME%"

if not exist %JAR_PATH% (
	echo [FATAL] - LDAP Directory Connector jar file not found at: "%JAR_PATH%"
	echo           1. Check the value of LDC_HOME ^(in your environment or in this script^)
	exit /b 1
)

rem --- Check for SECURE_PASSWORD variable
set LDC_CONFIG_PASSWORD=""
if defined SECURE_PASSWORD (
	set "LDC_CONFIG_PASSWORD=-p %SECURE_PASSWORD%"
) else (
	echo [FATAL] - environment variable SECURE_PASSWORD is not defined, define variable to start.
)

rem --- Confirm the Java Runtime Environment (JRE) is installed
set JVM_MIN_VERSION=18
for /f %%j in ("java.exe") do ( set "JVM_PATH=%%~dp$PATH:j" )
set JVM_PATH="%JVM_PATH%java.exe"
if not exist %JVM_PATH% (
	echo [FATAL] - java command not found
	echo           Configure your PATH or install Java version %JVM_MIN_VERSION% or greater
	echo           Download from http://www.oracle.com/technetwork/java/javase/downloads/index.html
	exit /b 1
)

rem --- Verify the JRE Version
for /f tokens^=2-5^ delims^=.-_^" %%j in ('java -fullversion 2^>^&1') do ( set "JVM_VERSION=%%j%%k" )
if %JVM_VERSION% LSS %JVM_MIN_VERSION% (
	echo [FATAL] - Java Runtime Environment %JVM_VERSION% is not supported.
	echo           Minimum JRE version supported is %JVM_MIN_VERSION%
	echo           Download from http://www.oracle.com/technetwork/java/javase/downloads/index.html
	exit /b 1
)

echo [INFO] - Starting the OneLogin LDAP Connector Secure Properties Utility using command:
echo java -cp %JAR_PATH% com.onelogin.ldc.console.SecureProperties %LDC_CONFIG_PASSWORD%
java -cp %JAR_PATH% com.onelogin.ldc.console.SecureProperties %LDC_CONFIG_PASSWORD% 

rem
rem --- EOF
