@echo off
rem --- Comment to enable shell debugging


rem -----------------------------------------------------------------------------
rem stop-ldc - Stop the OneLogin LDAP Direcrtory Connector version 2
rem 
rem This script is provided to stop the OneLogin LDAP Connector version 2
rem in Microsoft Windows environments. It works as follows:
rem 
rem 1. Checks for and validates the LDC_HOME environment, which must reference
rem    the directory where the LDAP Directory Connector is installed. Other
rem    directories, including: bin, conf, logs are expected to be direct child
rem    directories below LDC_HOME.
rem 
rem 2. If LDC_HOME is not set, it attempts to find it relative to the current
rem    working directory or the immediate parent directory.
rem 
rem 3. Constructs the path to the LDAP Directory Connector jar file at:
rem    LDC_HOME/libs/onelogin-ldc.jar
rem    and ensure it exists.
rem 
rem 4. Constructs the path to the default configuration file at:
rem    LDC_HOME/conf/ldc-default.conf
rem    and ensure it exists.
rem 
rem 5. Constructs the path to the site-specific configuration file at:
rem    LDC_HOME/conf/ldc.conf
rem    if exists.
rem 
rem 6. Constructs command line options.
rem 
rem 7. Constructs Java Virtual Machine configuration options.
rem 
rem 8. Launches the JVM on the LDAP Directory Connector StopClient program:
rem       if BACKGROUND="true", launches the JVM as a background process.
rem       else, launches the JVM as a foreground process.
rem -----------------------------------------------------------------------------
rem 

setlocal

rem --- Flag used to run as a foreground process or a background process.
rem 
rem    BACKGROUND - used by this script to start the Java Virtual Machine as
rem          a background process independent from the shell that started it
rem          or as a forground process under terminal control.
rem 
set BACKGROUND=false

rem --- The Java JAR file containing LDAP Directory Connector executable code
rem 
set JAR_FILE_NAME=onelogin-ldc.jar

rem --- Check for or set the LDAP Connector Home directory
if defined LDC_HOME (
	if not exist "%LDC_HOME%\" (
		echo [FATAL] - the LDC_HOME value ^(%LDC_HOME%^) is not a valid directory path
		echo           1. Check the environment value of LDC_HOME
		echo           2. Ensure the directory exists, is readable and contains the 'libs' directory
		echo              containing the %JAR_FILE_NAME% file
		exit /b 1
	) else (
	   if not exist %LDC_HOME%\libs\%JAR_FILE_NAME% (
			if exist .\libs\%JAR_FILE_NAME% (
				set LDC_HOME=%cd%
			) else (
				if exist ..\libs\%JAR_FILE_NAME% (
					set LDC_HOME=%cd%\..
				) else (
					echo [FATAL] - the LDC_HOME value is not set and could not be guessed
					echo           1. Set LDC_HOME value to your LDAP Directory Connector installation directory
					echo              Example: set LDC_HOME=C:\onelogin-ldc-2.2.12
					echo           2. or invoke this script from the directory where you installed the LDAP Directory Connector
					echo              Example: cd C:\onelogin-ldc-2.2.12; .\bin\start-ldc.bat
					echo           3. or invoke this script from the directory containing this script
					echo              Example: cd C:\onelogin-ldc-2.2.12/bin; .\start-ldc.bat
					exit /b 1
				)
			)
	   )
	)
) else (
	if exist .\libs\%JAR_FILE_NAME% (
		set LDC_HOME=%cd%
	) else (
		if exist ..\libs\%JAR_FILE_NAME% (
			set LDC_HOME=%cd%\..
		) else (
			echo [FATAL] - the LDC_HOME value is not set and could not be guessed
			echo           1. Set LDC_HOME value to your LDAP Directory Connector installation directory
			echo              Example: set LDC_HOME=C:\onelogin-ldc-2.2.12
			echo           2. or invoke this script from the directory where you installed the LDAP Directory Connector
			echo              Example: cd C:\onelogin-ldc-2.2.12; .\bin\start-ldc.bat
			echo           3. or invoke this script from the directory containing this script
			echo              Example: cd C:\onelogin-ldc-2.2.12/bin; .\start-ldc.bat
			exit /b 1
		)
	)

)

rem --- Check for the JAR file
set JAR_PATH="%LDC_HOME%\libs\%JAR_FILE_NAME%"

if not exist %JAR_PATH% (
	echo [FATAL] - LDAP Directory Connector jar file not found at: "%JAR_PATH%"
	echo           1. Check the value of LDC_HOME ^(in your environment or in this script^)
	exit /b 1
)

set LDC_DEFAULT_CONFIG_PATH="%LDC_HOME%\conf\ldc-default.conf"
if not exist %LDC_DEFAULT_CONFIG_PATH% (
	set LDC_DEFAULT_CONFIG_PATH=
) else (
	set "LDC_DEFAULT_CONFIG_PATH=-d %LDC_DEFAULT_CONFIG_PATH%"
)

rem --- Check for ldc.conf site-specific configuration File

set LDC_CONFIG_PATH="%LDC_HOME%\conf\ldc.conf"
if not exist %LDC_CONFIG_PATH% (
	echo [FATAL] - LDAP Directory Connector configuration file not found at: %LDC_CONFIG_PATH%
	echo           1. Check the value of LDC_HOME ^(in your environment or in this script^)
	exit /b 1
) else (
	set "LDC_CONFIG_PATH=-f %LDC_CONFIG_PATH%"
)

rem --- Confirm the Java Runtime Environment (JRE) is installed
set JVM_MIN_VERSION=18
for /f %%j in ("java.exe") do ( set "JVM_PATH=%%~dp$PATH:j" )
set JVM_PATH="%JVM_PATH%java.exe"
if not exist %JVM_PATH% (
	echo [FATAL] - java command not found
	echo           Configure your PATH or install Java version %JVM_MIN_VERSION% or greater
	echo           Download from http://www.oracle.com/technetwork/java/javase/downloads/index.html
	exit /b 1
)

rem --- Verify the JRE Version
for /f tokens^=2-5^ delims^=.-_^" %%j in ('java -fullversion 2^>^&1') do ( set "JVM_VERSION=%%j%%k" )
if %JVM_VERSION% LSS %JVM_MIN_VERSION% (
	echo [FATAL] - Java Runtime Environment %JVM_VERSION% is not supported.
	echo           Minimum JRE version supported is %JVM_MIN_VERSION%
	echo           Download from http://www.oracle.com/technetwork/java/javase/downloads/index.html
	exit /b 1
)

rem --- Set Java Virtual Machine (JVM) configuration options
set JVM_OPT=
set JVM_OPT=%JVM_OPT% -server

rem --- Start the LDAP Directory Connector
if "%BACKGROUND%" == "true" (
	if not exist "%LDC_HOME%\logs\" (
		mkdir "%LDC_HOME%\logs"
	)
	rem NOTE: the 'start /B call' command executes the JVM in another thread
	rem       This might happen if the login shell in which the LDAP connector is
	rem       started, times out and logs out the user. The net effect is that the
	rem       LDAP Connector JVM is executed as a 'background' process that survives
	rem       the shell that launched it.
	rem
	rem       stdout and sdterr - redirected to file: ldc_console.log
	echo [INFO] - Stopping the OneLogin LDAP Connector as a background process using command:
	echo start ^/B call java %JVM_OPT% -cp %JAR_PATH% com.onelogin.ldc.console.StopClient %LDC_DEFAULT_CONFIG_PATH% %LDC_CONFIG_PATH% 1^> %LDC_HOME%\logs\ldc_console.log 2^>^&1
	start /B call java %JVM_OPT% -cp %JAR_PATH% com.onelogin.ldc.console.StopClient %LDC_DEFAULT_CONFIG_PATH% %LDC_CONFIG_PATH% ^1^> %LDC_HOME%\logs\ldc_console.log ^2^>^&^1

) else (
	echo [INFO] - Stopping the OneLogin LDAP Connector as a foreground process using command:
	echo java %JVM_OPT% -cp %JAR_PATH% com.onelogin.ldc.console.StopClient %LDC_DEFAULT_CONFIG_PATH% %LDC_CONFIG_PATH%
	java %JVM_OPT% -cp %JAR_PATH% com.onelogin.ldc.console.StopClient %LDC_DEFAULT_CONFIG_PATH% %LDC_CONFIG_PATH%
	
)

if exist ".\logs\ldc.log" (
	del ".\logs\ldc.log"
)


rem 
rem --- EOF

